Index: /utils/CI/sette/input_AGRIF.cfg
===================================================================
--- /utils/CI/sette/input_AGRIF.cfg	(revision 9775)
+++ /utils/CI/sette/input_AGRIF.cfg	(revision 9776)
@@ -1,2 +1,2 @@
 ORCA2_ICE_v4.0.tar ORCA2_ICE_v4.0
-AGRIF_ICE_v4.0.tar AGRIF_ICE_v4.0
+AGRIF_DEMO_v4.0.tar AGRIF_DEMO_v4.0
Index: /utils/CI/sette/sette_rpt.sh
===================================================================
--- /utils/CI/sette/sette_rpt.sh	(revision 9775)
+++ /utils/CI/sette/sette_rpt.sh	(revision 9776)
@@ -424,5 +424,5 @@
  echo ""
  echo "   !----restart----!   "
- for restart_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WAGRIF_ICE_ST WSPITZ12_ST WISOMIP_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WSAS_BIPER_ST 
+ for restart_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WSPITZ12_ST WISOMIP_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WSAS_BIPER_ST 
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -433,5 +433,5 @@
  echo ""
  echo "   !----repro----!   "
- for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WORCA2_ICE_OBS_ST WAGRIF_ICE_ST WSPITZ12_ST WISOMIP_ST WVORTEX_ST WSAS_BIPER_ST
+ for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WORCA2_ICE_OBS_ST WAGRIF_DEMO_ST WSPITZ12_ST WISOMIP_ST WVORTEX_ST WSAS_BIPER_ST
  do
    reprotest $NEMO_VALID $repro_test $pass
@@ -442,6 +442,6 @@
  echo ""
  echo "   !----agrif check----!   "
- dir1=WAGRIF_ICE_NOAGRIF_ST
- dir2=WAGRIF_ICE_ST
+ dir1=WAGRIF_DEMO_NOAGRIF_ST
+ dir2=WAGRIF_DEMO_ST
  identictest $NEMO_VALID $dir1 $dir2 $pass 
 

Index: /utils/CI/sette/sette.sh
===================================================================
--- /utils/CI/sette/sette.sh	(revision 9775)
+++ /utils/CI/sette/sette.sh	(revision 9776)
@@ -138,5 +138,5 @@
 # SAS               :  5
 # ORCA2_ICE_OBS     :  6
 # AGRIF             :  7 & 8  test AGRIF in a double zoom configuration (AGRIF_ICE)
 #                               and check that key_agrif without zoom = no key_agrif
 # SPITZ12           :  9      regional configuration including sea-ice and tides (Spitzbergen)
@@ -949,11 +949,11 @@
     export TEST_NAME="LONG"
     cd ${MAIN_DIR}
-    . ./makenemo -m ${CMP_NAM} -n AGRIF_ICE_ST -r AGRIF_ICE -j 8 del_key "key_top"
-    cd ${SETTE_DIR}
-    . ./param.cfg
-    . ./all_functions.sh
-    . ./prepare_exe_dir.sh
-    JOB_FILE=${EXE_DIR}/run_job.sh
-    NPROC=32
+    . ./makenemo -m ${CMP_NAM} -n AGRIF_DEMO_ST -r AGRIF_DEMO -j 8 del_key ${DEL_KEYS}
+    cd ${SETTE_DIR}
+    . ./param.cfg
+    . ./all_functions.sh
+    . ./prepare_exe_dir.sh
+    JOB_FILE=${EXE_DIR}/run_job.sh
+    NPROC=16
     if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
     cd ${EXE_DIR}
@@ -964,10 +964,14 @@
     set_namelist 1_namelist_cfg cn_exp \"AGRIF_LONG\"
     set_namelist 1_namelist_cfg nn_it000 1
-    set_namelist 1_namelist_cfg nn_itend 80
-    set_namelist 1_namelist_cfg nn_stock 40
+    set_namelist 1_namelist_cfg nn_itend 20
+    set_namelist 1_namelist_cfg nn_stock 10
     set_namelist 2_namelist_cfg cn_exp \"AGRIF_LONG\"
     set_namelist 2_namelist_cfg nn_it000 1
-    set_namelist 2_namelist_cfg nn_itend 240
-    set_namelist 2_namelist_cfg nn_stock 120
+    set_namelist 2_namelist_cfg nn_itend 80
+    set_namelist 2_namelist_cfg nn_stock 40
+    set_namelist 3_namelist_cfg cn_exp \"AGRIF_LONG\"
+    set_namelist 3_namelist_cfg nn_it000 1
+    set_namelist 3_namelist_cfg nn_itend 240
+    set_namelist 3_namelist_cfg nn_stock 120
 
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -990,21 +994,29 @@
     set_namelist namelist_cfg nn_rstctl 2
     set_namelist 1_namelist_cfg cn_exp \"AGRIF_SHORT\"
-    set_namelist 1_namelist_cfg nn_it000 41
-    set_namelist 1_namelist_cfg nn_itend 80
-    set_namelist 1_namelist_cfg nn_stock 40
+    set_namelist 1_namelist_cfg nn_it000 11
+    set_namelist 1_namelist_cfg nn_itend 20
+    set_namelist 1_namelist_cfg nn_stock 10
     set_namelist 1_namelist_cfg ln_rstart .true.
     set_namelist 1_namelist_cfg nn_rstctl 2
     set_namelist 2_namelist_cfg cn_exp \"AGRIF_SHORT\"
-    set_namelist 2_namelist_cfg nn_it000 121
-    set_namelist 2_namelist_cfg nn_itend 240
-    set_namelist 2_namelist_cfg nn_stock 120
+    set_namelist 2_namelist_cfg nn_it000 41
+    set_namelist 2_namelist_cfg nn_itend 80
+    set_namelist 2_namelist_cfg nn_stock 40
     set_namelist 2_namelist_cfg ln_rstart .true.
     set_namelist 2_namelist_cfg nn_rstctl 2
+    set_namelist 3_namelist_cfg cn_exp \"AGRIF_SHORT\"
+    set_namelist 3_namelist_cfg nn_it000 121
+    set_namelist 3_namelist_cfg nn_itend 240
+    set_namelist 3_namelist_cfg nn_stock 120
+    set_namelist 3_namelist_cfg ln_rstart .true.
+    set_namelist 3_namelist_cfg nn_rstctl 2
     set_namelist namelist_cfg cn_ocerst_in \"AGRIF_LONG_00000010_restart\"
     set_namelist namelist_ice_cfg cn_icerst_in \"AGRIF_LONG_00000010_restart_ice\"
-    set_namelist 1_namelist_cfg cn_ocerst_in \"AGRIF_LONG_00000040_restart\"
-    set_namelist 1_namelist_ice_cfg cn_icerst_in \"AGRIF_LONG_00000040_restart_ice\"
-    set_namelist 2_namelist_cfg cn_ocerst_in \"AGRIF_LONG_00000120_restart\"
-    set_namelist 2_namelist_ice_cfg cn_icerst_in \"AGRIF_LONG_00000120_restart_ice\"
+    set_namelist 1_namelist_cfg cn_ocerst_in \"AGRIF_LONG_00000010_restart\"
+    set_namelist 1_namelist_ice_cfg cn_icerst_in \"AGRIF_LONG_00000010_restart_ice\"
+    set_namelist 2_namelist_cfg cn_ocerst_in \"AGRIF_LONG_00000040_restart\"
+    set_namelist 2_namelist_ice_cfg cn_icerst_in \"AGRIF_LONG_00000040_restart_ice\"
+    set_namelist 3_namelist_cfg cn_ocerst_in \"AGRIF_LONG_00000120_restart\"
+    set_namelist 3_namelist_ice_cfg cn_icerst_in \"AGRIF_LONG_00000120_restart_ice\"
 
     for (( i=1; i<=$NPROC; i++)) ; do
@@ -1013,8 +1025,10 @@
         ln -sf ../LONG/AGRIF_LONG_00000010_restart_${L_NPROC}.nc .
         ln -sf ../LONG/AGRIF_LONG_00000010_restart_ice_${L_NPROC}.nc .
-        ln -sf ../LONG/1_AGRIF_LONG_00000040_restart_${L_NPROC}.nc .
-        ln -sf ../LONG/1_AGRIF_LONG_00000040_restart_ice_${L_NPROC}.nc .
-        ln -sf ../LONG/2_AGRIF_LONG_00000120_restart_${L_NPROC}.nc .
-        ln -sf ../LONG/2_AGRIF_LONG_00000120_restart_ice_${L_NPROC}.nc .
+        ln -sf ../LONG/1_AGRIF_LONG_00000010_restart_${L_NPROC}.nc .
+        ln -sf ../LONG/1_AGRIF_LONG_00000010_restart_ice_${L_NPROC}.nc .
+        ln -sf ../LONG/2_AGRIF_LONG_00000040_restart_${L_NPROC}.nc .
+        ln -sf ../LONG/2_AGRIF_LONG_00000040_restart_ice_${L_NPROC}.nc .
+        ln -sf ../LONG/3_AGRIF_LONG_00000120_restart_${L_NPROC}.nc .
+        ln -sf ../LONG/3_AGRIF_LONG_00000120_restart_ice_${L_NPROC}.nc .
     done
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -1045,14 +1059,22 @@
     set_namelist namelist_cfg jpnj 8
     set_namelist namelist_cfg jpnij 32
+    set_namelist 1_namelist_cfg cn_exp \"AGRIF_48\"
     set_namelist 1_namelist_cfg nn_it000 1
-    set_namelist 1_namelist_cfg nn_itend 80
+    set_namelist 1_namelist_cfg nn_itend 20
     set_namelist 1_namelist_cfg jpni 4
     set_namelist 1_namelist_cfg jpnj 8
     set_namelist 1_namelist_cfg jpnij 32
+    set_namelist 2_namelist_cfg cn_exp \"AGRIF_48\"
     set_namelist 2_namelist_cfg nn_it000 1
-    set_namelist 2_namelist_cfg nn_itend 240
+    set_namelist 2_namelist_cfg nn_itend 80
     set_namelist 2_namelist_cfg jpni 4
     set_namelist 2_namelist_cfg jpnj 8
     set_namelist 2_namelist_cfg jpnij 32
+    set_namelist 3_namelist_cfg cn_exp \"AGRIF_48\"
+    set_namelist 3_namelist_cfg nn_it000 1
+    set_namelist 3_namelist_cfg nn_itend 240
+    set_namelist 3_namelist_cfg jpni 4
+    set_namelist 3_namelist_cfg jpnj 8
+    set_namelist 3_namelist_cfg jpnij 32
 
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -1079,14 +1101,22 @@
     set_namelist namelist_cfg jpnj 4
     set_namelist namelist_cfg jpnij 32
+    set_namelist 1_namelist_cfg cn_exp \"AGRIF_84\"
     set_namelist 1_namelist_cfg nn_it000 1
-    set_namelist 1_namelist_cfg nn_itend 80
+    set_namelist 1_namelist_cfg nn_itend 20
     set_namelist 1_namelist_cfg jpni 8
     set_namelist 1_namelist_cfg jpnj 4
     set_namelist 1_namelist_cfg jpnij 32
+    set_namelist 2_namelist_cfg cn_exp \"AGRIF_84\"
     set_namelist 2_namelist_cfg nn_it000 1
-    set_namelist 2_namelist_cfg nn_itend 240
+    set_namelist 2_namelist_cfg nn_itend 80
     set_namelist 2_namelist_cfg jpni 8
     set_namelist 2_namelist_cfg jpnj 4
     set_namelist 2_namelist_cfg jpnij 32
+    set_namelist 3_namelist_cfg cn_exp \"AGRIF_84\"
+    set_namelist 3_namelist_cfg nn_it000 1
+    set_namelist 3_namelist_cfg nn_itend 240
+    set_namelist 3_namelist_cfg jpni 8
+    set_namelist 3_namelist_cfg jpnj 4
+    set_namelist 3_namelist_cfg jpnij 32
 
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -1131,9 +1161,9 @@
 
 
 ## test code corruption with AGRIF (phase 2) ==> Compile without key_agrif (to be compared with AGRIF_ICE_ST/ORCA2)
 if [ ${config} -eq 8 ] ;  then
     export TEST_NAME="ORCA2"
     cd ${MAIN_DIR}
-    . ./makenemo -m ${CMP_NAM} -n AGRIF_ICE_NOAGRIF_ST -r AGRIF_ICE -j 8 del_key "key_top key_agrif"
+    . ./makenemo -m ${CMP_NAM} -n AGRIF_DEMO_NOAGRIF_ST -r AGRIF_DEMO -j 8 del_key "key_agrif"
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -1159,5 +1189,4 @@
 
 fi
-
 
 # -------
@@ -138,5 +138,5 @@
 # SAS               :  5
 # ORCA2_ICE_OBS     :  6
-# AGRIF             :  7 & 8  test AGRIF in a double zoom configuration (AGRIF_ICE)
+# AGRIF             :  7 & 8  test AGRIF in a double zoom configuration in the nordic seas + 1 zoom in the eq. Pacific (AGRIF_DEMO)
 #                               and check that key_agrif without zoom = no key_agrif
 # SPITZ12           :  9      regional configuration including sea-ice and tides (Spitzbergen)
@@ -1131,9 +1161,9 @@
 
 
-## test code corruption with AGRIF (phase 2) ==> Compile without key_agrif (to be compared with AGRIF_ICE_ST/ORCA2)
+## test code corruption with AGRIF (phase 2) ==> Compile without key_agrif (to be compared with AGRIF_DEMO_ST/ORCA2)
 if [ ${config} -eq 8 ] ;  then
     export TEST_NAME="ORCA2"